function plotSinErrors()
%PLOTSIMULATIONS Summary of this function goes here
%   Detailed explanation goes here

X0 = 0;
T = 0.5;

N = 12;
nSteps = zeros(N,1);
eulerError = zeros(N,1);
milsteinError = zeros(N,1);
for j=1:N
    nSteps(j) = 2^j;
    nPaths = 1000;

    dt = T/nSteps(j);
    
    dW = randn( nPaths, nSteps(j) )*sqrt(dt);
    
    exactPaths = sin(X0+cumsum(dW,2));    

    eulerPaths = simulateSinEuler( X0, dW, dt, nSteps(j) );
    eulerErrors = abs(eulerPaths(1:end,end)-exactPaths(1:end,end));
    eulerError(j) = ninetyPercentConfidence(eulerErrors);

    milsteinPaths = simulateSinMilstein( X0, dW, dt, nSteps(j) );
    milsteinErrors = abs(milsteinPaths(1:end,end)-exactPaths(1:end,end));
    milsteinError(j) = ninetyPercentConfidence(milsteinErrors);
end    

loglog( nSteps, eulerError, nSteps, milsteinError );
legend( 'Euler error', 'Milstein Error');
title( 'Accuracy of schemes');

end

function estimate = ninetyPercentConfidence( vector )
    m = mean( vector );
    s = std( vector );
    estimate = abs(m) + abs(s)*norminv(0.95)/sqrt( length( vector ));
end

