function plotVolatilitySmile()
%PLOTVOLATILITYSMILE Plot the volatility smile for the Heston model

% Fix some of the values for convenience
T = 1;
S0 = 100;
nPaths = 100000;
nSteps = 50;

kappa = 2;
theta = 0.04;
v0 = theta; % Start with variance at mean reversion level for convenience
xi = [0, 0.2, 0.4];
rho = 0;

K = 80:1:120;
vol = zeros( length(xi), length(K));
uVol = zeros( length(xi), length(K)); % upper estimate
lVol = zeros( length(xi), length(K)); % lower estimate
for j=1:length(xi)
    for i=1:length(K)
        rng('default');
        strike = K(i);
        [price, u, l] = priceCallByMonteCarlo( S0, v0, ...
                    kappa, theta, xi(j), rho, ...
                    T, nPaths, nSteps, ...
                    strike);
        vol(j,i) = computeImpliedVolatility( price, strike, T, S0, 0 );
        uVol(j,i) = computeImpliedVolatility( u, strike, T, S0, 0 );
        lVol(j,i) = computeImpliedVolatility( l, strike, T, S0, 0 );
    end
end    

figure();
plot( K, vol(1,:), K, vol(2,:), K, vol(3,:), K, uVol(1,:), K, lVol(1,:) );
legend('xi=0','xi=0.2', 'xi=0.4', '95% confidence, xi=0','95% confidence, xi=0' );
title( 'Heston model volatility smile');



end

