function [ T ] = simulateSinMilstein( T0, dW, dt, nSteps )
% Simulate the following process
% dT = -1/2 T dt + sqrt(1-T^2) dW
% Note this is obtained by taking the sin of brownian motion

currT = T0;
nPaths = size( dW, 1);
T = zeros(nPaths, nSteps );
for i=1:nSteps 
    currDW = dW(1:end,i);
    milsteinCorrection = -0.5*currT.*(currDW.^2 - dt);
    T(1:end,i) = currT - 0.5*currT*dt + sqrt(1-currT.^2).* currDW + milsteinCorrection;
    currT = T(1:end,i);
end    
    
end


